/*--------------------------------------------------------------------
 System functions.

 This scripts handles various system functions, like toggling of some
 configuration options (crossfading, shuffle, and repeat). Take note
 that this is for both the normal, shade and slim mode.
--------------------------------------------------------------------*/

#include "D:\Program Files\Winamp3/lib/std.mi"
#include "D:\Program Files\Winamp3/lib/config.mi"
#include "D:\Program Files\Winamp3/lib/pldir.mi"
  
Function setTempText(String txt);
Function emptyTempText();

Global Text Songticker;
Global Slider Seeker;
Global int Seeking;

Global Wac MainComp, Playlist;
Global Text Songticker, shadeSongticker, slimSongticker;
Global Timer Songtickertimer;

Class GuiObject HintObject;
Class ToggleButton HintToggleButton;

Global HintToggleButton ToggleXFade, ToggleShuffle, ToggleRepeat, sToggleXFade, sToggleShuffle, sToggleRepeat, slToggleXFade, slToggleShuffle, slToggleRepeat;

Class ConfigAttribute ToggleConfigAttribute;
Global ToggleConfigAttribute attr_repeat, attr_shuffle, attr_crossfade;


System.onScriptUnloading() {
  delete Songtickertimer;
}

System.onScriptLoaded() {

  // Timers won't start until .start(); is called
  Songtickertimer = new Timer;
  Songtickertimer.setDelay(1000);

  Group mainnormal = getContainer("main").getLayout("Normal").getObject("display");
  Layout mainslim = getContainer("main").getLayout("slim");
  Group displaygroup = getContainer("main").getLayout("shade").getObject("visual");

  // Get buttons
  ToggleXFade = mainnormal.getObject("Crossfade");
  ToggleShuffle = mainnormal.getObject("Shuffle");
  ToggleRepeat = mainnormal.getObject("Repeat");

  slToggleXFade = mainslim.getObject("Crossfade");
  slToggleShuffle = mainslim.getObject("Shuffle");
  slToggleRepeat = mainslim.getObject("Repeat");

  sToggleXFade = displaygroup.getObject("Crossfade");
  sToggleShuffle = displaygroup.getObject("Shuffle");
  sToggleRepeat = displaygroup.getObject("Repeat");

  // Get songticker
  Songticker = displaygroup.getObject("Songticker");
  shadeSongticker = mainnormal.getObject("Songticker");
  slimSongticker = mainslim.getObject("Songticker");
  Seeker = mainslim.getObject("Seeker");

  // Set buttons status
  ConfigItem item;
  item = Config.getItem("Playlist editor");
  if (item != NULL) {
    attr_repeat = item.getAttribute("repeat");
    attr_shuffle = item.getAttribute("shuffle");
  }
  item = Config.getItem("Audio options");
  if (item != NULL) {
    attr_crossfade = item.getAttribute("Enable crossfading");
  } 
  
  if (ToggleXFade != NULL && attr_crossfade != NULL) ToggleXFade.setActivated(StringToInteger(attr_crossfade.getData()));
  if (ToggleShuffle != NULL && attr_shuffle != NULL) ToggleShuffle.setActivated(StringToInteger(attr_shuffle.getData()));
  if (ToggleRepeat != NULL && attr_repeat != NULL) ToggleRepeat.setActivated(StringToInteger(attr_repeat.getData()));

  if (sToggleXFade != NULL && attr_crossfade != NULL) sToggleXFade.setActivated(StringToInteger(attr_crossfade.getData()));
  if (sToggleShuffle != NULL && attr_shuffle != NULL) sToggleShuffle.setActivated(StringToInteger(attr_shuffle.getData()));
  if (sToggleRepeat != NULL && attr_repeat != NULL) sToggleRepeat.setActivated(StringToInteger(attr_repeat.getData()));

  if (slToggleXFade != NULL && attr_crossfade != NULL) slToggleXFade.setActivated(StringToInteger(attr_crossfade.getData()));
  if (slToggleShuffle != NULL && attr_shuffle != NULL) slToggleShuffle.setActivated(StringToInteger(attr_shuffle.getData()));
  if (slToggleRepeat != NULL && attr_repeat != NULL) slToggleRepeat.setActivated(StringToInteger(attr_repeat.getData()));
}


Songticker.onLeftButtonDblClk(int x, int y) {
  PlDir.showCurrentlyPlayingEntry();
}

Songtickertimer.onTimer() {
  Songticker.setText("");
  shadeSongticker.setText("");
  slimSongticker.setText("");
  stop();
}

HintToggleButton.onLeftButtonDown(int x, int y) {
  if (HintToggleButton == ToggleXFade) setTempText("Crossfade");
  else if (HintToggleButton == sToggleXFade) setTempText("Crossfade");
  else if (HintToggleButton == slToggleXFade) setTempText("Crossfade");
  else if (HintToggleButton == ToggleRepeat) setTempText("Repeat");
  else if (HintToggleButton == sToggleRepeat) setTempText("Repeat");
  else if (HintToggleButton == slToggleRepeat) setTempText("Repeat");
  else if (HintToggleButton == ToggleShuffle) setTempText("Shuffle");
  else if (HintToggleButton == sToggleShuffle) setTempText("Shuffle");
  else if (HintToggleButton == slToggleShuffle) setTempText("Shuffle");
}

//HintToggleButton.onLeftButtonUp(int x, int y) {
//  emptyTempText();
//}

HintToggleButton.onToggle(int onoff) {
  String cmd, txt;
//  Wac dest;
  ConfigAttribute item;
  item = NULL;
  if (HintToggleButton == ToggleXFade || HintToggleButton == sToggleXFade || HintToggleButton == slToggleXFade) {
    item = attr_crossfade;
    txt = "Crossfade";
  } else if (HintToggleButton == ToggleRepeat || HintToggleButton == sToggleRepeat || HintToggleButton == slToggleRepeat) {
    item = attr_repeat;
    txt = "Repeat";
  } else if (HintToggleButton == ToggleShuffle || HintToggleButton == sToggleShuffle || HintToggleButton == slToggleShuffle) {
    item = attr_shuffle;
    txt = "Shuffle";
  }
  if (item != NULL) {
    item.setData(IntegerToString(onoff));
    String s;
    if (onoff) s = " on"; else s = " off";
    setTempText(txt + s);
  }
}

setTempText(String txt) {
  Songtickertimer.stop();
  Songticker.setText(txt);
  shadeSongticker.setText(txt);
  slimSongticker.setText(txt);
  Songtickertimer.start();
}

emptyTempText() {
  Songticker.setText("");
  shadeSongticker.setText("");
  slimSongticker.setText("");
  Songtickertimer.stop();
}

ToggleConfigAttribute.onDataChanged() {
  ToggleButton t = NULL;
  if (ToggleConfigAttribute == attr_crossfade) t = ToggleXFade;
  else if (ToggleConfigAttribute == attr_crossfade) t = sToggleXFade;
  else if (ToggleConfigAttribute == attr_crossfade) t = slToggleXFade;
  else if (ToggleConfigAttribute == attr_shuffle) t = ToggleShuffle;
  else if (ToggleConfigAttribute == attr_shuffle) t = sToggleShuffle;
  else if (ToggleConfigAttribute == attr_shuffle) t = slToggleShuffle;
  else if (ToggleConfigAttribute == attr_repeat) t = ToggleRepeat;
  else if (ToggleConfigAttribute == attr_repeat) t = sToggleRepeat;
  else if (ToggleConfigAttribute == attr_repeat) t = slToggleRepeat;
  if (t != NULL)
    t.setActivated(StringToInteger(getData()));
}
 
Seeker.onSetPosition(int p) {
  if (seeking) {
    Float f;
    f = p;
    f = f / 255 * 100;
    Float len = getPlayItemLength();
    if (len != 0) {
      int np = len * f / 100;
      setTempText("Seek to: " + integerToTime(np));
    }
  }
}

Seeker.onLeftButtonDown(int x, int y) {
  seeking = 1;
}

Seeker.onLeftButtonUp(int x, int y) {
  seeking = 0;
  setTempText("");
}

Seeker.onSetFinalPosition(int p) {
  slimSongticker.setAlternateText("");
}
 